Change an attribute name from layout_box to ctsv_layout_box.

This is to avoid conflicts with other libraries (if used together).

Change-Id: Ie09f340a2a44f9639a780df354526830850207e2
diff --git a/apps/CtsVerifier/res/layout-land/sensor_test.xml b/apps/CtsVerifier/res/layout-land/sensor_test.xml
index f547978..ee96d41 100644
--- a/apps/CtsVerifier/res/layout-land/sensor_test.xml
+++ b/apps/CtsVerifier/res/layout-land/sensor_test.xml
@@ -17,7 +17,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
             android:orientation="vertical"
             android:layout_width="match_parent"
             android:layout_height="match_parent"
diff --git a/apps/CtsVerifier/res/layout-port/sensor_test.xml b/apps/CtsVerifier/res/layout-port/sensor_test.xml
index b4eca4d..4f5332e 100644
--- a/apps/CtsVerifier/res/layout-port/sensor_test.xml
+++ b/apps/CtsVerifier/res/layout-port/sensor_test.xml
@@ -17,7 +17,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
             android:orientation="vertical"
             android:layout_width="match_parent"
             android:layout_height="match_parent">
diff --git a/apps/CtsVerifier/res/layout-small/sensor_test.xml b/apps/CtsVerifier/res/layout-small/sensor_test.xml
index eefa5fa..7895596 100644
--- a/apps/CtsVerifier/res/layout-small/sensor_test.xml
+++ b/apps/CtsVerifier/res/layout-small/sensor_test.xml
@@ -18,7 +18,7 @@
     android:layout_width="match_parent"
     android:layout_height="match_parent">
     <ScrollView android:id="@+id/log_scroll_view"
-            app:layout_box="all"
+            app:ctsv_layout_box="all"
             android:fillViewport="true"
             android:layout_height="match_parent"
             android:layout_width="match_parent">
diff --git a/apps/CtsVerifier/res/layout/ca_boot_notify.xml b/apps/CtsVerifier/res/layout/ca_boot_notify.xml
index 0ceece1..31edd27 100644
--- a/apps/CtsVerifier/res/layout/ca_boot_notify.xml
+++ b/apps/CtsVerifier/res/layout/ca_boot_notify.xml
@@ -18,7 +18,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
       android:orientation="vertical" android:layout_width="fill_parent"
       android:layout_height="fill_parent">
 
diff --git a/apps/CtsVerifier/res/layout/car_dock_test_main.xml b/apps/CtsVerifier/res/layout/car_dock_test_main.xml
index c568b54..afefa52 100644
--- a/apps/CtsVerifier/res/layout/car_dock_test_main.xml
+++ b/apps/CtsVerifier/res/layout/car_dock_test_main.xml
@@ -17,7 +17,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
         android:layout_width="fill_parent"
         android:layout_height="fill_parent"
         android:orientation="vertical" >
diff --git a/apps/CtsVerifier/res/layout/fs_main.xml b/apps/CtsVerifier/res/layout/fs_main.xml
index 8a78c81..8f6029b 100644
--- a/apps/CtsVerifier/res/layout/fs_main.xml
+++ b/apps/CtsVerifier/res/layout/fs_main.xml
@@ -17,7 +17,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
              android:orientation="vertical"
              android:layout_width="match_parent"
              android:layout_height="match_parent">
diff --git a/apps/CtsVerifier/res/layout/intent_driven_test.xml b/apps/CtsVerifier/res/layout/intent_driven_test.xml
index bd9e4ca..75580b9 100644
--- a/apps/CtsVerifier/res/layout/intent_driven_test.xml
+++ b/apps/CtsVerifier/res/layout/intent_driven_test.xml
@@ -4,7 +4,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
         android:layout_width="match_parent"
         android:layout_height="match_parent"
         android:orientation="vertical">
diff --git a/apps/CtsVerifier/res/layout/js_charging.xml b/apps/CtsVerifier/res/layout/js_charging.xml
index 8d9ed1d..e19bdba 100644
--- a/apps/CtsVerifier/res/layout/js_charging.xml
+++ b/apps/CtsVerifier/res/layout/js_charging.xml
@@ -3,7 +3,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <ScrollView app:layout_box="all"
+    <ScrollView app:ctsv_layout_box="all"
         android:layout_width="match_parent"
         android:layout_height="match_parent">
         <LinearLayout
diff --git a/apps/CtsVerifier/res/layout/js_connectivity.xml b/apps/CtsVerifier/res/layout/js_connectivity.xml
index b0e2824..ae0725d 100644
--- a/apps/CtsVerifier/res/layout/js_connectivity.xml
+++ b/apps/CtsVerifier/res/layout/js_connectivity.xml
@@ -3,7 +3,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <ScrollView app:layout_box="all"
+    <ScrollView app:ctsv_layout_box="all"
         android:layout_width="match_parent"
         android:layout_height="match_parent">
         <LinearLayout
diff --git a/apps/CtsVerifier/res/layout/js_idle.xml b/apps/CtsVerifier/res/layout/js_idle.xml
index 5289b98..200e66f 100644
--- a/apps/CtsVerifier/res/layout/js_idle.xml
+++ b/apps/CtsVerifier/res/layout/js_idle.xml
@@ -3,7 +3,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <ScrollView app:layout_box="all"
+    <ScrollView app:ctsv_layout_box="all"
         android:layout_width="match_parent"
         android:layout_height="match_parent">
         <LinearLayout
diff --git a/apps/CtsVerifier/res/layout/list_content.xml b/apps/CtsVerifier/res/layout/list_content.xml
index 8670283..b0e5354 100644
--- a/apps/CtsVerifier/res/layout/list_content.xml
+++ b/apps/CtsVerifier/res/layout/list_content.xml
@@ -22,7 +22,7 @@
 
     <ListView
         android:id="@android:id/list"
-        app:layout_box="all"
+        app:ctsv_layout_box="all"
         android:layout_width="match_parent"
         android:layout_height="match_parent" />
 </android.support.wearable.view.BoxInsetLayout>
diff --git a/apps/CtsVerifier/res/layout/location_mode_main.xml b/apps/CtsVerifier/res/layout/location_mode_main.xml
index 1768434..3ce532a 100644
--- a/apps/CtsVerifier/res/layout/location_mode_main.xml
+++ b/apps/CtsVerifier/res/layout/location_mode_main.xml
@@ -18,7 +18,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
         android:layout_width="match_parent"
         android:layout_height="match_parent"
         android:orientation="vertical"
diff --git a/apps/CtsVerifier/res/layout/pa_main.xml b/apps/CtsVerifier/res/layout/pa_main.xml
index 832af71..8cc9d3a 100644
--- a/apps/CtsVerifier/res/layout/pa_main.xml
+++ b/apps/CtsVerifier/res/layout/pa_main.xml
@@ -17,7 +17,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <RelativeLayout app:layout_box="all"
+    <RelativeLayout app:ctsv_layout_box="all"
         android:layout_width="match_parent"
         android:layout_height="match_parent" >
 
diff --git a/apps/CtsVerifier/res/layout/pass_fail_list.xml b/apps/CtsVerifier/res/layout/pass_fail_list.xml
index cdd40e1..7be427c 100644
--- a/apps/CtsVerifier/res/layout/pass_fail_list.xml
+++ b/apps/CtsVerifier/res/layout/pass_fail_list.xml
@@ -18,7 +18,7 @@
     android:layout_width="match_parent"
     android:layout_height="match_parent">
 
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
             android:orientation="vertical"
             android:layout_width="match_parent"
             android:layout_height="match_parent"
diff --git a/apps/CtsVerifier/res/layout/poa_main.xml b/apps/CtsVerifier/res/layout/poa_main.xml
index 41bade0..1100d7f 100644
--- a/apps/CtsVerifier/res/layout/poa_main.xml
+++ b/apps/CtsVerifier/res/layout/poa_main.xml
@@ -17,7 +17,7 @@
     xmlns:app="http://schemas.android.com/apk/res-auto"
     android:layout_width="match_parent"
     android:layout_height="match_parent">
-    <LinearLayout app:layout_box="all"
+    <LinearLayout app:ctsv_layout_box="all"
         android:layout_width="fill_parent"
         android:layout_height="fill_parent"
         android:orientation="vertical" >
diff --git a/apps/CtsVerifier/res/layout/pwa_widgets.xml b/apps/CtsVerifier/res/layout/pwa_widgets.xml
index 6204d3e..380b8f0 100644
--- a/apps/CtsVerifier/res/layout/pwa_widgets.xml
+++ b/apps/CtsVerifier/res/layout/pwa_widgets.xml
@@ -19,13 +19,13 @@
     android:layout_height="match_parent">
 
      <TextureView
-         app:layout_box="all"
+         app:ctsv_layout_box="all"
          android:id="@+id/texture_view"
          android:layout_width="match_parent"
          android:layout_height="match_parent" />
 
      <LinearLayout
-         app:layout_box="all"
+         app:ctsv_layout_box="all"
          android:layout_width="fill_parent"
          android:layout_height="wrap_content"
          android:orientation="vertical" >
diff --git a/apps/CtsVerifier/res/values/attrs.xml b/apps/CtsVerifier/res/values/attrs.xml
index 71a1ba6..9490c87 100644
--- a/apps/CtsVerifier/res/values/attrs.xml
+++ b/apps/CtsVerifier/res/values/attrs.xml
@@ -15,7 +15,7 @@
   -->
 <resources>
     <declare-styleable name="BoxInsetLayout_Layout">
-        <attr name="layout_box">
+        <attr name="ctsv_layout_box">
             <flag name="left" value="0x01" />
             <flag name="top" value="0x02" />
             <flag name="right" value="0x04" />
diff --git a/apps/CtsVerifier/src/android/support/wearable/view/BoxInsetLayout.java b/apps/CtsVerifier/src/android/support/wearable/view/BoxInsetLayout.java
index 77d6a21..7718bd1 100644
--- a/apps/CtsVerifier/src/android/support/wearable/view/BoxInsetLayout.java
+++ b/apps/CtsVerifier/src/android/support/wearable/view/BoxInsetLayout.java
@@ -34,10 +34,10 @@
 /**
  * BoxInsetLayout is a screen shape-aware FrameLayout that can box its children
  * in the center square of a round screen by using the
  * {@code layout_box} attribute. The values for this attribute specify the
  * child's edges to be boxed in:
  * {@code left|top|right|bottom} or {@code all}.
  * The {@code layout_box} attribute is ignored on a device with a rectangular
  * screen.
  */
 @TargetApi(Build.VERSION_CODES.KITKAT_WATCH)
@@ -383,7 +383,7 @@
     }
 
     /**
      * adds {@code layout_box} attribute to layout parameters
      */
     public static class LayoutParams extends FrameLayout.LayoutParams {
 
@@ -399,7 +399,7 @@
         public LayoutParams(Context context, AttributeSet attrs) {
             super(context, attrs);
             TypedArray a = context.obtainStyledAttributes(attrs,  R.styleable.BoxInsetLayout_Layout, 0, 0);
-            boxedEdges = a.getInt(R.styleable.BoxInsetLayout_Layout_layout_box, BOX_NONE);
+            boxedEdges = a.getInt(R.styleable.BoxInsetLayout_Layout_ctsv_layout_box, BOX_NONE);
             a.recycle();
         }
@@ -34,10 +34,10 @@
  * BoxInsetLayout is a screen shape-aware FrameLayout that can box its children
  * in the center square of a round screen by using the
- * {@code layout_box} attribute. The values for this attribute specify the
+ * {@code ctsv_layout_box} attribute. The values for this attribute specify the
  * child's edges to be boxed in:
  * {@code left|top|right|bottom} or {@code all}.
@@ -34,10 +34,10 @@
  * child's edges to be boxed in:
  * {@code left|top|right|bottom} or {@code all}.
- * The {@code layout_box} attribute is ignored on a device with a rectangular
+ * The {@code ctsv_layout_box} attribute is ignored on a device with a rectangular
  * screen.
  */
@@ -383,7 +383,7 @@
 
     /**
-     * adds {@code layout_box} attribute to layout parameters
+     * adds {@code ctsv_layout_box} attribute to layout parameters
      */
     public static class LayoutParams extends FrameLayout.LayoutParams {